==> aws-android-sdk-ddb-2.2.10-sources.jar: com/amazonaws/services/dynamodbv2/model/ReturnItemCollectionMetrics.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.dynamodbv2.model;

/**
 * Return Item Collection Metrics
 */
public enum ReturnItemCollectionMetrics {
    
    SIZE("SIZE"),
    NONE("NONE");

    private String value;

    private ReturnItemCollectionMetrics(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return ReturnItemCollectionMetrics corresponding to the value
     */
    public static ReturnItemCollectionMetrics fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("SIZE".equals(value)) {
            return ReturnItemCollectionMetrics.SIZE;
        } else if ("NONE".equals(value)) {
            return ReturnItemCollectionMetrics.NONE;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-android-sdk-ddb-2.3.8-sources.jar: com/amazonaws/services/dynamodbv2/model/ReturnItemCollectionMetrics.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.dynamodbv2.model;

import java.util.HashMap;
import java.util.Map;

/**
 * Return Item Collection Metrics
 */
public enum ReturnItemCollectionMetrics {

    SIZE("SIZE"),
    NONE("NONE");

    private String value;

    private ReturnItemCollectionMetrics(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return value;
    }

    private static final Map<String, ReturnItemCollectionMetrics> enumMap;
    static {
        enumMap = new HashMap<String, ReturnItemCollectionMetrics>();
        enumMap.put("SIZE", SIZE);
        enumMap.put("NONE", NONE);
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value real value
     * @return ReturnItemCollectionMetrics corresponding to the value
     */
    public static ReturnItemCollectionMetrics fromValue(String value) {
        if (value == null || value.isEmpty()) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if (enumMap.containsKey(value)) {
            return enumMap.get(value);
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
